import type { SocketReconnectOptions } from './reconnectStrategy';
import type { SocketConnectOptions } from './socket';
/**
 * The connection status of the Genesis client.
 * @public
 */
export type ConnectionStatus = 'connected' | 'disconnected' | 'busy';
/**
 * Configuration options for the Connect (WS) instance.
 * @public
 */
export interface ConnectConfig {
    /**
     * Options for the initial connection.
     */
    connect: SocketConnectOptions;
    /**
     * Options for automatic reconnection on connection loss.
     */
    reconnect: SocketReconnectOptions;
}
/**
 * Configuration options for http polling.
 * @public
 */
export interface PollingConfiguration {
    /**
     * The temporary polling frequency.
     */
    TEMP_FREQUENCY: number;
    /**
     * The expected amount of HTTP polling attempts to be performed.
     * @remarks TEMP_FREQUENCY * AMOUNT_OF_POLLS = the total polling time/duration
     */
    AMOUNT_OF_POLLS: number;
    /**
     * The queries to be polled.
     */
    QUERIES: string[];
}
/**
 * Configuration options for http connection.
 * @public
 */
export interface HttpPollingConfig {
    /**
     * The frequency of polling.
     */
    POLLING_FREQUENCY?: number;
    /**
     * The interval map of polling.
     */
    POLLING_INTERVAL_MAP?: {
        [resource: string]: number;
    };
    /**
     * The map of polling configuration.
     */
    POLLING_MAP?: {
        [key: string]: PollingConfiguration;
    };
}
/**
 * Configuration options for the Connect (HTTP) instance.
 * @public
 */
export interface HttpConnectConfig {
    /**
     * Configuration options for http polling.
     */
    polling: HttpPollingConfig;
}
/**
 * Configuration options for the Connect (WS) instance.
 * @internal
 */
export declare const ConnectConfig: import("@microsoft/fast-foundation").InterfaceSymbol<ConnectConfig>;
/**
 * Configuration options for the Connect (HTTP) instance.
 * @internal
 */
export declare const HttpConnectConfig: import("@microsoft/fast-foundation").InterfaceSymbol<HttpConnectConfig>;
//# sourceMappingURL=connect.types.d.ts.map