import { JSONSerializer } from '@genesislcap/foundation-utils';
import { BehaviorSubject, Observable } from 'rxjs';
import type { Metadata, SchemaResponse } from '../metadata';
import { MetaCache } from '../metadata';
import { Session } from '../session';
import { Connect } from './connect';
import { HttpConnectConfig } from './connect.types';
import { Http } from './http';
import { CommitParams, Message, MessageBuilder, RequestParams } from './message';
import { SocketObservable } from './socket';
/**
 * The default configuration for connecting to an HTTP service.
 * @public
 */
export declare const defaultHttpConnectConfig: HttpConnectConfig;
/**
 * The default implementation for the Connect interface (HTTP-only).
 * @public
 */
export declare class DefaultHttpConnect implements Connect {
    http: Http;
    private messageBuilder;
    private session;
    private metaCache;
    private serializer;
    private config;
    host: string;
    isWorking: boolean;
    private _isConnected;
    isConnectedSubject: BehaviorSubject<boolean>;
    isConnected$: Observable<boolean>;
    get isConnected(): boolean;
    set isConnected(value: boolean);
    private ongoingTurbo?;
    /**
     * A map of active messages in "polling" mode.
     * @remarks Equivalent to messaged being streamed in a WebSocket connection.
     * @internal
     */
    private streams;
    constructor(http: Http, messageBuilder: MessageBuilder, session: Session, metaCache: MetaCache, serializer: JSONSerializer, config?: HttpConnectConfig);
    /**
     * Checks if the host is available by sending a heartbeat ping message and waiting for the response.
     * @internal
     * @returns A Promise that resolves to `true` if the host is available, and `false` otherwise.
     */
    private checkHost;
    send<T>(message: Message<any>, needsHandling?: boolean): Promise<any>;
    httpMode(): boolean;
    setValidSession(valid: boolean): void;
    connect(host: string): Promise<boolean>;
    disconnect(): void;
    snapshot(resourceName: string, params?: any): Promise<Message>;
    stream(resourceName: string, onMessage: Function, onError: Function, params?: any): SocketObservable<Message>;
    private getMessage;
    getMoreRows(sourceRef: string): Promise<Message>;
    getMoreColumns(sourceRef: string): Promise<Message>;
    dataLogoff(streamSourceRef: string): Promise<Message>;
    getMetadata(resourceName: string, useCache?: boolean): Promise<Metadata>;
    getJSONSchema(resourceName: string): Promise<SchemaResponse>;
    request(resourceName: string, params?: RequestParams): Promise<Message>;
    getAvailableResources(params?: any): Promise<Message>;
    commitEvent(eventName: string, params?: CommitParams): Promise<Message>;
    private maybeTurbo;
    private updateIntervals;
    private handlePollingIntervalMapUpdate;
    private static getBody;
    private static getUrl;
}
/**
 * The DI token for the Connect interface (HTTP-only).
 * @internal
 */
export declare const HttpConnect: import("@microsoft/fast-foundation").InterfaceSymbol<Connect>;
//# sourceMappingURL=http.connect.d.ts.map