import { BehaviorSubject } from 'rxjs';
/**
 * `SerializedSocketStatus` provides the serialize state of the web socket.
 * @public
 */
export interface SerializedSocketStatus {
    /**
     * When the socket has been configured for use.
     */
    isConfigured: boolean;
    isConnecting: boolean;
    isConnected: boolean;
    isDisconnected: boolean;
    isDisconnectedByServer: boolean;
    isReconnecting: boolean;
    reconnectionLimitReached: boolean;
    hasValidSession: boolean;
    readonly closedCode: number;
    readonly closedReason: string;
    readonly closedClean: boolean;
}
/**
 * `SocketStatus` provides the state of the web socket.
 * @public
 */
export interface SocketStatus extends SerializedSocketStatus {
    isConnectedSubject: BehaviorSubject<boolean>;
    serialize(): SerializedSocketStatus;
    onClose(closeEvent: CloseEvent): void;
}
/**
 * Default SocketStatus implementation.
 * @public
 */
export declare class DefaultSocketStatus implements SocketStatus {
    isConfigured: boolean;
    isConnecting: boolean;
    isConnected: boolean;
    isReconnecting: boolean;
    reconnectionLimitReached: boolean;
    hasValidSession: boolean;
    closedCode: any;
    closedReason: any;
    closedClean: any;
    get isDisconnected(): boolean;
    get isDisconnectedByServer(): boolean;
    isConnectedSubject: BehaviorSubject<boolean>;
    protected isConnectedChanged(): void;
    protected isReconnectingChanged(): void;
    protected resetClosedState(): void;
    serialize(): SerializedSocketStatus;
    onClose(event: CloseEvent): void;
}
/**
 * SocketStatus DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export declare const SocketStatus: import("@microsoft/fast-foundation").InterfaceSymbol<SocketStatus>;
/**
 * Gets SocketStatus from the DI container.
 *
 * @remarks
 * A utility method for host applications that are not using decorators or the DI container.
 *
 * @example
 * ```ts
 * import { getSocketStatus } from '@genesislcap/foundation-comms';
 * ...
 * private socketStatus = getSocketStatus();
 * ```
 *
 * @public
 */
export declare function getSocketStatus(): SocketStatus;
//# sourceMappingURL=socket.status.d.ts.map